@@ -1,4 +1,4 @@
-/* Copyright (c) 2015-2016 Dovecot authors, see the included COPYING file */
+/* Copyright (c) 2015-2018 Dovecot authors, see the included COPYING file */
 
 #ifndef PUSH_NOTIFICATION_EVENT_MESSAGENEW_H
 #define PUSH_NOTIFICATION_EVENT_MESSAGENEW_H
@@ -23,6 +23,13 @@ struct push_notification_event_messagenew_data {
     int date_tz;
     /* PUSH_NOTIFICATION_MESSAGE_BODY_SNIPPET */
     const char *snippet;
+    /* PUSH_NOTIFICATION_MESSAGE_FLAGS */
+    bool flags_set;
+    enum mail_flags flags;
+    /* PUSH_NOTIFICATION_MESSAGE_KEYWORDS */
+    const char *const *keywords;
+    /* PUSH_NOTIFICATION_MESSAGE_HDR_MESSAGE_ID */
+    const char *message_id;
 };
 
 
